from billetterie.admin import admin
from django.contrib.admin import ModelAdmin, TabularInline

from guichet.models import (
    PaypalAccount,
    LydiaAccount,
    Event,
    UserManager,
    GroupManager,
    Ticket,
    Registration,
    LogEntry,
    Option,
    Info_Sup,
    Info_Sup_Choice,
    Info_Sup_Choice_Choices,
    Info_Sup_Int,
    Info_Sup_Float,
    Info_Sup_File,
    Info_Sup_Recv,
    Info_Sup_Recv_Short_Text,
    Info_Sup_Recv_Long_Text,
    Info_Sup_Recv_Choice,
    Info_Sup_Recv_Int,
    Info_Sup_Recv_Float,
    Info_Sup_Recv_File,
)


class EventAdmin(ModelAdmin):
    list_display = ("name", "event_confidentiality", "start_date", "end_date")
    search_fields = ("name",)
    list_filter = ("event_confidentiality",)


class UserManagerAdmin(ModelAdmin):
    list_display = ("event", "user", "access")
    search_fields = ("event__name", "access", "user__login_inp_net", "user__email")
    list_filter = ("access",)


class GroupManagerAdmin(ModelAdmin):
    list_display = ("event", "group", "bureau_only", "access")
    search_fields = ("event__name", "access", "group__displayName")
    list_filter = ("access",)


class TicketAdmin(ModelAdmin):
    list_display = (
        "event",
        "name",
        "max_purchase_date",
    )
    search_fields = ("name",)
    list_filter = ("event",)


class RegistrationAdmin(ModelAdmin):
    list_display = ("owner", "ticket", "info_state", "paid", "used", "opposed", "refund")
    list_filter = ("payment_method", "used", "info_state")


class OptionAdmin(ModelAdmin):
    list_display = ("ticket", "name")
    list_filter = ("ticket",)


class LogAdmin(ModelAdmin):
    list_display = ("event", "user", "reason", "operation")
    search_fields = ("user", "event", "registration")
    list_filter = ("reason", "event")
    actions = []

    def has_delete_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_module_permission(self, request):
        return request.user.is_superuser

    def has_view_permission(self, request, obj=None):
        return request.user.is_superuser


class InfoAdmin(ModelAdmin):
    list_display = ("ticket", "name", "after_payement", "type_info")
    search_fields = ("ticket__name", "ticket__event__name", "name")
    list_filter = ("ticket__event", "after_payement", "type_info")

    def get_readonly_fields(self, request, obj=None):
        if obj:
            return self.readonly_fields + ("type_info",)
        return self.readonly_fields


class InlineInfoChoicesAdmin(TabularInline):
    model = Info_Sup_Choice_Choices
    extra = 0


class InfoChoicesAdmin(ModelAdmin):
    list_display = ("ticket", "name", "after_payement", "type_info")
    search_fields = ("ticket__name", "ticket__event__name", "name")
    list_filter = ("ticket__event", "after_payement", "type_info")
    inlines = (InlineInfoChoicesAdmin,)

    def get_readonly_fields(self, request, obj=None):
        if obj:
            return self.readonly_fields + ("type_info",)
        return self.readonly_fields


class InfoRecvAdmin(ModelAdmin):
    list_display = ("get_ticket", "reference", "get_reg_pk", "state", "get_type_info")
    search_fields = ("registration__pk", "reference__name")
    list_filter = ("registration__ticket__event", "state", "reference__type_info")

    def get_readonly_fields(self, request, obj=None):
        if obj:
            return self.readonly_fields + ("reference",)
        return self.readonly_fields

    def get_ticket(self, obj):
        return obj.registration.ticket

    def get_reg_pk(self, obj):
        return obj.registration.pk

    def get_type_info(self, obj):
        return obj.reference.type_info


admin.register(Event, EventAdmin)
admin.register(UserManager, UserManagerAdmin)
admin.register(GroupManager, GroupManagerAdmin)
admin.register(Ticket, TicketAdmin)
admin.register(Registration, RegistrationAdmin)
admin.register(LogEntry, LogAdmin)
admin.register(PaypalAccount)
admin.register(LydiaAccount)
admin.register(Option, OptionAdmin)
admin.register(Info_Sup, InfoAdmin)
admin.register(Info_Sup_Choice, InfoChoicesAdmin)
admin.register(Info_Sup_Int, InfoAdmin)
admin.register(Info_Sup_Float, InfoAdmin)
admin.register(Info_Sup_File, InfoAdmin)
admin.register(Info_Sup_Recv, InfoRecvAdmin)
admin.register(Info_Sup_Recv_Short_Text, InfoRecvAdmin)
admin.register(Info_Sup_Recv_Long_Text, InfoRecvAdmin)
admin.register(Info_Sup_Recv_Choice, InfoRecvAdmin)
admin.register(Info_Sup_Recv_Int, InfoRecvAdmin)
admin.register(Info_Sup_Recv_Float, InfoRecvAdmin)
admin.register(Info_Sup_Recv_File, InfoRecvAdmin)
